@@ -10,14 +10,14 @@ test_that('forward.search run', {
     FS <- forward.search(holzinger, nfact, print.messages = FALSE)
     expect_is(FS, 'forward.search')
     expect_is(plot(FS), 'trellis')
-    expect_equal(FS$LD[c(1, length(FS$LD))], c(3.717805, 26.293829), tolerance = 1e-5)
+    expect_equal(FS$GOF[c(1, length(FS$GOF))], c(3.717805, 26.293829), tolerance = 1e-5)
     
     #-------------------------------------------------------------------    
-    suppressMessages(model <- specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))    
+    suppressMessages(model <- sem::specifyModel(file='sem-model/sem-model.txt', quiet=TRUE))    
     FS.outlier <- suppressWarnings(forward.search(holzinger.outlier, model, print.messages = FALSE))
     expect_is(FS.outlier, 'forward.search')
     expect_is(plot(FS.outlier), 'trellis')
-    expect_equal(FS.outlier$LD[c(1, length(FS.outlier$LD))], 
+    expect_equal(FS.outlier$GOF[c(1, length(FS.outlier$GOF))], 
                  c(34.64542, 161.01480), tolerance = 1e-5)
     
     #---- lavaan
@@ -28,7 +28,7 @@ test_that('forward.search run', {
                                  p.base = .7)
     expect_is(FS.outlier, 'forward.search')
     expect_is(plot(FS.outlier), 'trellis')
-    expect_equal(FS.outlier$LD[c(1, length(FS.outlier$LD))], 
+    expect_equal(FS.outlier$GOF[c(1, length(FS.outlier$GOF))], 
                  c(26.96743, 111.39844), tolerance = 1e-5)
     
 })
\ No newline at end of file
